DataOps | MLOps for humans
==========================

omega|ml is the innovative Python-native DataOps and MLOps platform
that provides a ready-to-use data science workbench, development
and runtime environment. Works from laptop to cloud.

.. toctree::
   :maxdepth: 2

   quickstart/index
   guide/index
   admin/index
   devguide/index
   reference/index
   nb/index
   screenshots
